.. _swh-alter:

.. include:: README.rst

.. toctree::
   :maxdepth: 1
   :caption: Overview

   usage
   removal-algorithm
   recovery-bundles

.. only:: standalone_package_doc

   Indices and tables
   ------------------

   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
